@@ -28,6 +28,7 @@ from .literals import (
     OpenSearchWarmPartitionInstanceTypeType,
     OptionStateType,
     OutboundConnectionStatusCodeType,
+    OverallChangeStatusType,
     PackageStatusType,
     ReservedInstancePaymentOptionType,
     RollbackOnDisableType,
@@ -72,6 +73,9 @@ __all__ = (
     "AutoTuneTypeDef",
     "CancelServiceSoftwareUpdateRequestRequestTypeDef",
     "CancelServiceSoftwareUpdateResponseTypeDef",
+    "ChangeProgressDetailsTypeDef",
+    "ChangeProgressStageTypeDef",
+    "ChangeProgressStatusDetailsTypeDef",
     "ClusterConfigStatusTypeDef",
     "ClusterConfigTypeDef",
     "CognitoOptionsStatusTypeDef",
@@ -94,6 +98,8 @@ __all__ = (
     "DeletePackageResponseTypeDef",
     "DescribeDomainAutoTunesRequestRequestTypeDef",
     "DescribeDomainAutoTunesResponseTypeDef",
+    "DescribeDomainChangeProgressRequestRequestTypeDef",
+    "DescribeDomainChangeProgressResponseTypeDef",
     "DescribeDomainConfigRequestRequestTypeDef",
     "DescribeDomainConfigResponseTypeDef",
     "DescribeDomainRequestRequestTypeDef",
@@ -423,6 +429,40 @@ CancelServiceSoftwareUpdateResponseTypeDef = TypedDict(
     },
 )
 
+ChangeProgressDetailsTypeDef = TypedDict(
+    "ChangeProgressDetailsTypeDef",
+    {
+        "ChangeId": str,
+        "Message": str,
+    },
+    total=False,
+)
+
+ChangeProgressStageTypeDef = TypedDict(
+    "ChangeProgressStageTypeDef",
+    {
+        "Name": str,
+        "Status": str,
+        "Description": str,
+        "LastUpdated": datetime,
+    },
+    total=False,
+)
+
+ChangeProgressStatusDetailsTypeDef = TypedDict(
+    "ChangeProgressStatusDetailsTypeDef",
+    {
+        "ChangeId": str,
+        "StartTime": datetime,
+        "Status": OverallChangeStatusType,
+        "PendingProperties": List[str],
+        "CompletedProperties": List[str],
+        "TotalNumberOfStages": int,
+        "ChangeProgressStages": List["ChangeProgressStageTypeDef"],
+    },
+    total=False,
+)
+
 ClusterConfigStatusTypeDef = TypedDict(
     "ClusterConfigStatusTypeDef",
     {
@@ -671,6 +711,36 @@ DescribeDomainAutoTunesResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredDescribeDomainChangeProgressRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeDomainChangeProgressRequestRequestTypeDef",
+    {
+        "DomainName": str,
+    },
+)
+_OptionalDescribeDomainChangeProgressRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeDomainChangeProgressRequestRequestTypeDef",
+    {
+        "ChangeId": str,
+    },
+    total=False,
+)
+
+
+class DescribeDomainChangeProgressRequestRequestTypeDef(
+    _RequiredDescribeDomainChangeProgressRequestRequestTypeDef,
+    _OptionalDescribeDomainChangeProgressRequestRequestTypeDef,
+):
+    pass
+
+
+DescribeDomainChangeProgressResponseTypeDef = TypedDict(
+    "DescribeDomainChangeProgressResponseTypeDef",
+    {
+        "ChangeProgressStatus": "ChangeProgressStatusDetailsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeDomainConfigRequestRequestTypeDef = TypedDict(
     "DescribeDomainConfigRequestRequestTypeDef",
     {
@@ -884,6 +954,7 @@ DomainConfigTypeDef = TypedDict(
         "DomainEndpointOptions": "DomainEndpointOptionsStatusTypeDef",
         "AdvancedSecurityOptions": "AdvancedSecurityOptionsStatusTypeDef",
         "AutoTuneOptions": "AutoTuneOptionsStatusTypeDef",
+        "ChangeProgressDetails": "ChangeProgressDetailsTypeDef",
     },
     total=False,
 )
@@ -973,6 +1044,7 @@ _OptionalDomainStatusTypeDef = TypedDict(
         "DomainEndpointOptions": "DomainEndpointOptionsTypeDef",
         "AdvancedSecurityOptions": "AdvancedSecurityOptionsTypeDef",
         "AutoTuneOptions": "AutoTuneOptionsOutputTypeDef",
+        "ChangeProgressDetails": "ChangeProgressDetailsTypeDef",
     },
     total=False,
 )
@@ -1815,6 +1887,7 @@ UpgradeDomainResponseTypeDef = TypedDict(
         "TargetVersion": str,
         "PerformCheckOnly": bool,
         "AdvancedOptions": Dict[str, str],
+        "ChangeProgressDetails": "ChangeProgressDetailsTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
